package com.muyu.data.processing.controller;


import com.muyu.common.core.utils.uuid.UUID;
import com.muyu.common.iotdb.config.IotDBConfig;
import com.muyu.common.kafka.constants.KafkaConstants;
import com.muyu.common.rabbit.constants.RabbitConstants;
import jakarta.annotation.Resource;
import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.web.bind.annotation.*;
import lombok.extern.slf4j.Slf4j;

/**
 * 测试控制层
 * @Author: 胡杨
 * @Name: Test
 * @Description:
 * @CreatedDate: 2024/9/27 上午10:54
 * @FilePath: com.muyu.data.processing.controller
 */
@Slf4j
@RestController
@RequestMapping("/Test")
public class TestController {
    @Resource
    private KafkaProducer<String,String> kafkaProducer;
    @Resource
    private RabbitTemplate rabbitTemplate;
    @Resource
    private IotDBConfig iotDBConfig;

    @GetMapping("/testKafka")
    public void sendMsg(@RequestParam("msg") String msg) {
        try {
            // 测试数据
            String jsonString = """
                    [{
                        "key": "vin",
                        "label": "VIN码",
                        "type": "String",
                        "value": "vin131413534474"
                    },{
                        "key": "timestamp",
                        "label": "时间戳",
                        "type": "String",
                        "value": "1727534036893"
                    },{
                        "key": "latitude",
                        "label": "纬度",
                        "type": "String",
                        "value": "66.898"
                    },{
                        "key": "longitude",
                        "label": "经度",
                        "type": "String",
                        "value": "99.12"
                    }]""";
            ProducerRecord<String, String> producerRecord = new ProducerRecord<>(KafkaConstants.KafkaTopic, jsonString);
            kafkaProducer.send(producerRecord);
            System.out.println("同步消息发送成功: " + jsonString);
        } catch (Exception e) {
            e.printStackTrace();
            System.out.println("同步消息发送失败");
        }
    }

    @GetMapping("/testRabbit/GoOnline")
    public void testRabbitGoOnline(@RequestParam("msg") String msg) {
        rabbitTemplate.convertAndSend(RabbitConstants.GO_ONLINE_QUEUE, msg, message -> {
            message.getMessageProperties().setMessageId(UUID.randomUUID().toString().replace("-",""));
            return message;
        });
    }

    @GetMapping("/testRabbit/Downline")
    public void testRabbitDownline(@RequestParam("msg") String msg) {
        rabbitTemplate.convertAndSend(RabbitConstants.DOWNLINE_QUEUE, msg, message -> {
            message.getMessageProperties().setMessageId(UUID.randomUUID().toString().replace("-",""));
            return message;
        });
    }

    @GetMapping("/insertData")
    public void insertData(@RequestParam("deviceId") String deviceId, @RequestParam("time") long time, @RequestParam("value") double value) throws Exception {
        String sql = String.format("insert into root.one.%s(timestamp, temperature) values (%d, %f)", deviceId, time, value);
        iotDBConfig.iotSession().executeNonQueryStatement(sql);
    }
}
